0.9.9 API documentation: GLM_GTC_matrix_transform

| 0.9.9 API documentation

- Main Page
- Modules
- Files

GLM_GTC_matrix_transform
Recommended extensions

Include <glm/gtc/matrix_transform.hpp> to use the features of this extension. More...

Include <glm/gtc/matrix_transform.hpp> to use the features of this extension.

Defines functions that generate common transformation matrices.

The matrices generated by this extension use standard OpenGL fixed-function conventions. For example, the lookAt function generates a transform from world space into the specific eye space that the projective matrix functions (perspective, ortho, etc) are designed to expect. The OpenGL compatibility specifications defines the particular layout of this eye space.